@@ -3,9 +3,14 @@ inc_path = os.path.dirname(os.path.dirname(os.path.abspath(__file__)))
 sys.path.insert(0, inc_path)
 
 import pytest
-import internetarchive.mine
 
+try:
+    import internetarchive.mine
+    py_test_mine = True
+except ImportError:
+    py_test_mine = False
 
+@pytest.mark.skipif('py_test_mine == False', reason='requires internetarchive[speedups]')
 def test_mine():
     def general_tests(ids):
         miner = internetarchive.mine.Mine(ids)
